==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Downloads/language/lang-spanish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_PREVIOUS","Pgina Anterior");
define("_NEXT","Pgina Siguiente");
define("_CATEGORY","Categora");
define("_CATEGORIES","Categoras");
define("_LVOTES","Votos");
define("_TOTALVOTES","Votos Totales:");
define("_THEREARE","Hay");
define("_NOMATCHES","No hay registros para su consulta");
define("_SCOMMENTS","Comentarios");
define("_UNKNOWN","Desconocido");
define("_DOWNLOADS","Downloads");
define("_FILESIZE","Tamao del archivo");
define("_VERSION","Versin");
define("_DESCRIPTION","Descripcin");
define("_AUTHOR","Autor");
define("_HOMEPAGE","Pgina de Inicio");
define("_DOWNLOADNOW","Descargar este archivo ahora.");
define("_FILEURL","URL del archivo");
define("_ADDDOWNLOAD","Aadir Descarga");
define("_DOWNLOADSMAIN","Indice");
define("_DOWNLOADCOMMENTS","Comentarios de la descarga");
define("_DOWNLOADSMAINCAT","Categora de la descarga");
define("_ADDADOWNLOAD","Agregar una descarga");
define("_DOWNLOADALREADYEXT","ERROR: Este URL ya est en nuestra Base de Datos!");
define("_DOWNLOADNOTITLE","ERROR: Necesitas poner un Titulo para tu URL!");
define("_DOWNLOADNOURL","ERROR: Necesitas poner un URL para tu URL!");
define("_DOWNLOADNODESC","ERROR: Necesitas poner una Descripcin para tu URL!");
define("_DOWNLOADRECEIVED","Recibimos tu Propuesta. Gracias!");
define("_CHECKFORIT","No has escrito un E-Mail. De todas maneras, revisaremos tu enlace pronto.");
define("_NEWDOWNLOADS","Nuevas Descargas");
define("_TOTALNEWDOWNLOADS","Nmero total de nuevos enlaces");
define("_TRATEDDOWNLOADS","total de descargas valoradas");
define("_SORTDOWNLOADSBY","Ordenar los enlaces por");
define("_DOWNLOADPROFILE","Perfil de descarga");
define("_DOWNLOADRATINGDET","Detalles de la valoracin del enlace");
define("_EDITTHISDOWNLOAD","Editar esta descarga");
define("_DOWNLOADRATING","Valoracin de la descarga");
define("_PROMOTE02","Una manera de ligar el formulario de evaluacin es poner este simple texto:");
define("_PROMOTE03","Si quieres ms que un simple texto, puedes utilizar un pequeo botn como:");
define("_PROMOTE04","Si haces trampas en esto, quitaremos tu enlace. Una vez aclarado esto, as es como se ve el formulario de valoracin.");
define("_DOWNLOADVOTE","Vota!");
define("_REQUESTDOWNLOADMOD","Pedir la modificacin de la descarga");
define("_DOWNLOADID","ID de la Descarga");
define("_DATE","Fecha");
define("_TO","Para");
define("_NEW","Nuevo");
define("_POPULAR","Popular");
define("_TOPRATED","Mejores valorados");
define("_ADDITIONALDET","Detalles adicionales");
define("_EDITORREVIEW","Resea del editor");
define("_REPORTBROKEN","Informar de un enlace roto");
define("_AND","y");
define("_INDB","en nuestra base de datos");
define("_INSTRUCTIONS","Instrucciones");
define("_USERANDIP","El nombre de usuario y el IP sern registrados, as que por favor no abuses del sistema.");
define("_LDESCRIPTION","Descripcin: (255 caracteres mx.)");
define("_LASTWEEK","Ultima Semana");
define("_LAST30DAYS","Ultimos 30 das");
define("_1WEEK","1 Semana");
define("_2WEEKS","2 Semanas");
define("_30DAYS","30 Das");
define("_SHOW","Ver");
define("_DAYS","das");
define("_ADDEDON","Agregado el");
define("_RATING","Valoracin");
define("_DETAILS","Detalles");
define("_OF","de");
define("_TVOTESREQ","mnimo de votos necesarios");
define("_SHOWTOP","Mostrar Top");
define("_MOSTPOPULAR","Ms Popular - Top");
define("_OFALL","de todo");
define("_POPULARITY","Popularidad");
define("_SELECTPAGE","Seleccionar Pgina");
define("_MAIN","Principal");
define("_NEWTODAY","Nuevo Hoy");
define("_NEWLAST3DAYS","Nuevo en los ltimos 3 das");
define("_NEWTHISWEEK","Nuevo esta semana");
define("_POPULARITY1","Popularidad (de menos a ms hits)");
define("_POPULARITY2","Popularidad (de ms a menos hits)");
define("_TITLEAZ","Ttulo (A - Z)");
define("_TITLEZA","Ttulo (Z - A)");
define("_RATING1","Valoracin (de menor a mayor)");
define("_RATING2","Valoracin (de mayor a menor)");
define("_SEARCHRESULTS4","Buscar resultados por");
define("_USUBCATEGORIES","Sub-Categoras");
define("_TRY2SEARCH","Intenta buscar");
define("_INOTHERSENGINES","en otros Motores de Bsqueda");
define("_EDITORIAL","Editorial");
define("_EDITORIALBY","Editorial por");
define("_NOEDITORIAL","El editorial no est actualmente disponible en este sitio web.");
define("_RATETHISSITE","Valorar este sitio web");
define("_ISTHISYOURSITE","Es este tu recurso?");
define("_ALLOWTORATE","Permite que los usuarios lo valoren desde tu sitio Web!");
define("_OVERALLRATING","Valoracin General");
define("_TOTALOF","Total de");
define("_USER","Usuario");
define("_USERAVGRATING","Valoracin promedio de los usuarios");
define("_NUMRATINGS","Num. de valoraciones");
define("_REGISTEREDUSERS","Usuarios registrados");
define("_NUMBEROFRATINGS","Nmero de valoraciones");
define("_NOREGUSERSVOTES","No hay votos de usuarios registrados");
define("_BREAKDOWNBYVAL","Histograma por valoracin");
define("_LTOTALVOTES","votos totales");
define("_HIGHRATING","Alta valoracin");
define("_LOWRATING","Baja valoracin");
define("_NUMOFCOMMENTS","Nmero de comentarios");
define("_WEIGHNOTE","* Nota: Este sitio diferencia los votos de los usuarios registrados de los no registrados");
define("_NOUNREGUSERSVOTES","No hay votos de no registrados");
define("_WEIGHOUTNOTE","** Nota: Este sitio diferencia los votos de los usuarios registrados de los forneos");
define("_NOOUTSIDEVOTES","Votos de usuarios");
define("_OUTSIDEVOTERS","Votos de annimos");
define("_UNREGISTEREDUSERS","Usuarios no registrados");
define("_PROMOTEYOURSITE","Promover tu sitio web");
define("_PROMOTE01","Tal vez te interesa unas de la opciones que tenemos para la 'Valoracin de otros sitios'. Estas te permiten poner una imagen (o un formulario de votacin) en tu sitio Web para incrementar sus votos. Por favor elije una de estas opciones:");
define("_TEXTLINK","Texto del enlace");
define("_HTMLCODE1","El cdigo HTML que puedes usar en este caso, es el siguiente:");
define("_THENUMBER","El Nmero");
define("_IDREFER","en el cdigo HTML referencia tu ID de sitio en la Base de Datos de $sitename. Verifica que este nmero este presente.");
define("_BUTTONLINK","Botn de Enlace");
define("_RATEIT","Vota por este sitio");
define("_HTMLCODE2","El cdigo fuente para el botn anterior es:");
define("_REMOTEFORM","Formulario de valoracin remota");
define("_VOTE4THISSITE","Votar por este sitio");
define("_HTMLCODE3","Usando este formulario permitir a los usuarios valorar tu sitio directamente desde tu pgina y ser grabada aqu. El formulario anterior est desconectado, pero el siguiente cdigo trabajar si lo copias y pegas en tu pgina. El cdigo es el siguiente:");
define("_PROMOTE05","Gracias!, y buena suerte con tu valoracin.");
define("_STAFF","Plantilla");
define("_THANKSBROKEN","Gracias por ayudar a mantener la integridad de este directorio.");
define("_SECURITYBROKEN","Por razones de seguridad tu nombre de usuario y direccin IP sern temporalmente registrados.");
define("_THANKSFORINFO","Gracias por la informacin.");
define("_LOOKTOREQUEST","Analizaremos tu peticin pronto.");
define("_SENDREQUEST","Enviar Peticin");
define("_THANKSTOTAKETIME","Gracias por tu tiempo en la evaluacin de este sitio en");
define("_RETURNTO","Volver a");
define("_RATENOTE1","Por favor no votes por el mismo enlace ms de una vez");
define("_RATENOTE2","La escala va de 1 a 10, siendo 1 Pobre y 10 Excelente.");
define("_RATENOTE3","Trate de ser objetivo en tu voto, si se recibe siempre 1  10, la valoracin no ser til.");
define("_RATENOTE5","No votes por tu propio recurso o el de tu competidor.");
define("_YOUAREREGGED","Eres un usuario registrado y ests conectado.");
define("_FEELFREE2ADD","Sintete libre de agregar un comentario sobre este sitio.");
define("_YOUARENOTREGGED","No eres un usuario registrado o no ests conectado.");
define("_IFYOUWEREREG","Si estuvieras registrado podras haber publicado comentarios en este sitio web.");
define("_TITLE","Ttulo");
define("_MODIFY","Modificar");
define("_COMPLETEVOTE1","Tu vote es apreciado.");
define("_COMPLETEVOTE2","T ya has votado por este recurso en los pasados $anonwaitdays da(s).");
define("_COMPLETEVOTE3","Vota por un recurso slo una vez.<br>Todos los votos sern revisados.");
define("_COMPLETEVOTE4","No puedes votar por un recurso que t enviste.<br>Todos los votos sern revisados.");
define("_COMPLETEVOTE5","No has seleccionado un valor - Voto no registrado");
define("_COMPLETEVOTE6","Slo se admite un voto por direccin IP cada $outsidewaitdays da(s).");
define("_LINKSDATESTRING","%d-%m-%Y");
define("_AUTHORNAME","Author's Name");
define("_AUTHOREMAIL","Author's Email");
define("_DOWNLOADNAME","Program Name");
define("_ADDTHISFILE","Add this file");
define("_INBYTES","in bytes");
define("_RATERESOURCE","Rate Resource");
define("_DSUBMITONCE","Submit a unique download only once.");
define("_DPOSTPENDING","All downloads are posted pending verification.");
define("_DTOTALFORLAST","Total new downloads for last");
define("_DBESTRATED","Best Rated Downloads - Top");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Downloads/language/lang-spanish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_PREVIOUS","Pgina Anterior");
define("_NEXT","Pgina Siguiente");
define("_CATEGORY","Categora");
define("_CATEGORIES","Categoras");
define("_LVOTES","Votos");
define("_TOTALVOTES","Votos Totales:");
define("_THEREARE","Hay");
define("_NOMATCHES","No hay registros para su consulta");
define("_SCOMMENTS","Comentarios");
define("_UNKNOWN","Desconocido");
define("_DOWNLOADS","Downloads");
define("_FILESIZE","Tamao del archivo");
define("_VERSION","Versin");
define("_DESCRIPTION","Descripcin");
define("_AUTHOR","Autor");
define("_HOMEPAGE","Pgina de Inicio");
define("_DOWNLOADNOW","Descargar este archivo ahora.");
define("_FILEURL","URL del archivo");
define("_ADDDOWNLOAD","Aadir Descarga");
define("_DOWNLOADSMAIN","Indice");
define("_DOWNLOADCOMMENTS","Comentarios de la descarga");
define("_DOWNLOADSMAINCAT","Categora de la descarga");
define("_ADDADOWNLOAD","Agregar una descarga");
define("_DOWNLOADALREADYEXT","ERROR: Este URL ya est en nuestra Base de Datos!");
define("_DOWNLOADNOTITLE","ERROR: Necesitas poner un Titulo para tu URL!");
define("_DOWNLOADNOURL","ERROR: Necesitas poner un URL para tu URL!");
define("_DOWNLOADNODESC","ERROR: Necesitas poner una Descripcin para tu URL!");
define("_DOWNLOADRECEIVED","Recibimos tu Propuesta. Gracias!");
define("_CHECKFORIT","No has escrito un E-Mail. De todas maneras, revisaremos tu enlace pronto.");
define("_NEWDOWNLOADS","Nuevas Descargas");
define("_TOTALNEWDOWNLOADS","Nmero total de nuevos enlaces");
define("_TRATEDDOWNLOADS","total de descargas valoradas");
define("_SORTDOWNLOADSBY","Ordenar los enlaces por");
define("_DOWNLOADPROFILE","Perfil de descarga");
define("_DOWNLOADRATINGDET","Detalles de la valoracin del enlace");
define("_EDITTHISDOWNLOAD","Editar esta descarga");
define("_DOWNLOADRATING","Valoracin de la descarga");
define("_PROMOTE02","Una manera de ligar el formulario de evaluacin es poner este simple texto:");
define("_PROMOTE03","Si quieres ms que un simple texto, puedes utilizar un pequeo botn como:");
define("_PROMOTE04","Si haces trampas en esto, quitaremos tu enlace. Una vez aclarado esto, as es como se ve el formulario de valoracin.");
define("_DOWNLOADVOTE","Vota!");
define("_REQUESTDOWNLOADMOD","Pedir la modificacin de la descarga");
define("_DOWNLOADID","ID de la Descarga");
define("_DATE","Fecha");
define("_TO","Para");
define("_NEW","Nuevo");
define("_POPULAR","Popular");
define("_TOPRATED","Mejores valorados");
define("_ADDITIONALDET","Detalles adicionales");
define("_EDITORREVIEW","Resea del editor");
define("_REPORTBROKEN","Informar de un enlace roto");
define("_AND","y");
define("_INDB","en nuestra base de datos");
define("_INSTRUCTIONS","Instrucciones");
define("_USERANDIP","El nombre de usuario y el IP sern registrados, as que por favor no abuses del sistema.");
define("_LDESCRIPTION","Descripcin: (255 caracteres mx.)");
define("_LASTWEEK","Ultima Semana");
define("_LAST30DAYS","Ultimos 30 das");
define("_1WEEK","1 Semana");
define("_2WEEKS","2 Semanas");
define("_30DAYS","30 Das");
define("_SHOW","Ver");
define("_DAYS","das");
define("_ADDEDON","Agregado el");
define("_RATING","Valoracin");
define("_DETAILS","Detalles");
define("_OF","de");
define("_TVOTESREQ","mnimo de votos necesarios");
define("_SHOWTOP","Mostrar Top");
define("_MOSTPOPULAR","Ms Popular - Top");
define("_OFALL","de todo");
define("_POPULARITY","Popularidad");
define("_SELECTPAGE","Seleccionar Pgina");
define("_MAIN","Principal");
define("_NEWTODAY","Nuevo Hoy");
define("_NEWLAST3DAYS","Nuevo en los ltimos 3 das");
define("_NEWTHISWEEK","Nuevo esta semana");
define("_POPULARITY1","Popularidad (de menos a ms hits)");
define("_POPULARITY2","Popularidad (de ms a menos hits)");
define("_TITLEAZ","Ttulo (A - Z)");
define("_TITLEZA","Ttulo (Z - A)");
define("_RATING1","Valoracin (de menor a mayor)");
define("_RATING2","Valoracin (de mayor a menor)");
define("_SEARCHRESULTS4","Buscar resultados por");
define("_USUBCATEGORIES","Sub-Categoras");
define("_TRY2SEARCH","Intenta buscar");
define("_INOTHERSENGINES","en otros Motores de Bsqueda");
define("_EDITORIAL","Editorial");
define("_EDITORIALBY","Editorial por");
define("_NOEDITORIAL","El editorial no est actualmente disponible en este sitio web.");
define("_RATETHISSITE","Valorar este sitio web");
define("_ISTHISYOURSITE","Es este tu recurso?");
define("_ALLOWTORATE","Permite que los usuarios lo valoren desde tu sitio Web!");
define("_OVERALLRATING","Valoracin General");
define("_TOTALOF","Total de");
define("_USER","Usuario");
define("_USERAVGRATING","Valoracin promedio de los usuarios");
define("_NUMRATINGS","Num. de valoraciones");
define("_REGISTEREDUSERS","Usuarios registrados");
define("_NUMBEROFRATINGS","Nmero de valoraciones");
define("_NOREGUSERSVOTES","No hay votos de usuarios registrados");
define("_BREAKDOWNBYVAL","Histograma por valoracin");
define("_LTOTALVOTES","votos totales");
define("_HIGHRATING","Alta valoracin");
define("_LOWRATING","Baja valoracin");
define("_NUMOFCOMMENTS","Nmero de comentarios");
define("_WEIGHNOTE","* Nota: Este sitio diferencia los votos de los usuarios registrados de los no registrados");
define("_NOUNREGUSERSVOTES","No hay votos de no registrados");
define("_WEIGHOUTNOTE","** Nota: Este sitio diferencia los votos de los usuarios registrados de los forneos");
define("_NOOUTSIDEVOTES","Votos de usuarios");
define("_OUTSIDEVOTERS","Votos de annimos");
define("_UNREGISTEREDUSERS","Usuarios no registrados");
define("_PROMOTEYOURSITE","Promover tu sitio web");
define("_PROMOTE01","Tal vez te interesa unas de la opciones que tenemos para la 'Valoracin de otros sitios'. Estas te permiten poner una imagen (o un formulario de votacin) en tu sitio Web para incrementar sus votos. Por favor elije una de estas opciones:");
define("_TEXTLINK","Texto del enlace");
define("_HTMLCODE1","El cdigo HTML que puedes usar en este caso, es el siguiente:");
define("_THENUMBER","El Nmero");
define("_IDREFER","en el cdigo HTML referencia tu ID de sitio en la Base de Datos de $sitename. Verifica que este nmero este presente.");
define("_BUTTONLINK","Botn de Enlace");
define("_RATEIT","Vota por este sitio");
define("_HTMLCODE2","El cdigo fuente para el botn anterior es:");
define("_REMOTEFORM","Formulario de valoracin remota");
define("_VOTE4THISSITE","Votar por este sitio");
define("_HTMLCODE3","Usando este formulario permitir a los usuarios valorar tu sitio directamente desde tu pgina y ser grabada aqu. El formulario anterior est desconectado, pero el siguiente cdigo trabajar si lo copias y pegas en tu pgina. El cdigo es el siguiente:");
define("_PROMOTE05","Gracias!, y buena suerte con tu valoracin.");
define("_STAFF","Plantilla");
define("_THANKSBROKEN","Gracias por ayudar a mantener la integridad de este directorio.");
define("_SECURITYBROKEN","Por razones de seguridad tu nombre de usuario y direccin IP sern temporalmente registrados.");
define("_THANKSFORINFO","Gracias por la informacin.");
define("_LOOKTOREQUEST","Analizaremos tu peticin pronto.");
define("_SENDREQUEST","Enviar Peticin");
define("_THANKSTOTAKETIME","Gracias por tu tiempo en la evaluacin de este sitio en");
define("_RETURNTO","Volver a");
define("_RATENOTE1","Por favor no votes por el mismo enlace ms de una vez");
define("_RATENOTE2","La escala va de 1 a 10, siendo 1 Pobre y 10 Excelente.");
define("_RATENOTE3","Trate de ser objetivo en tu voto, si se recibe siempre 1  10, la valoracin no ser til.");
define("_RATENOTE5","No votes por tu propio recurso o el de tu competidor.");
define("_YOUAREREGGED","Eres un usuario registrado y ests conectado.");
define("_FEELFREE2ADD","Sintete libre de agregar un comentario sobre este sitio.");
define("_YOUARENOTREGGED","No eres un usuario registrado o no ests conectado.");
define("_IFYOUWEREREG","Si estuvieras registrado podras haber publicado comentarios en este sitio web.");
define("_TITLE","Ttulo");
define("_MODIFY","Modificar");
define("_COMPLETEVOTE1","Tu vote es apreciado.");
define("_COMPLETEVOTE2","T ya has votado por este recurso en los pasados $anonwaitdays da(s).");
define("_COMPLETEVOTE3","Vota por un recurso slo una vez.<br>Todos los votos sern revisados.");
define("_COMPLETEVOTE4","No puedes votar por un recurso que t enviste.<br>Todos los votos sern revisados.");
define("_COMPLETEVOTE5","No has seleccionado un valor - Voto no registrado");
define("_COMPLETEVOTE6","Slo se admite un voto por direccin IP cada $outsidewaitdays da(s).");
define("_LINKSDATESTRING","%d-%m-%Y");
define("_AUTHORNAME","Author's Name");
define("_AUTHOREMAIL","Author's Email");
define("_DOWNLOADNAME","Program Name");
define("_ADDTHISFILE","Add this file");
define("_INBYTES","in bytes");
define("_RATERESOURCE","Rate Resource");
define("_DSUBMITONCE","Submit a unique download only once.");
define("_DPOSTPENDING","All downloads are posted pending verification.");
define("_DTOTALFORLAST","Total new downloads for last");
define("_DBESTRATED","Best Rated Downloads - Top");

?>
